@@ -34,7 +34,10 @@ class ConcreteData:
         data_path = download(cache_dir, 'concrete.xls', URL)
         self.df = pd.read_excel(data_path)
         table = self.df.to_numpy()
-        train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
+        if self.val_split != 0:
+            train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
+        else:
+            train, val = table, []
         self.data = {
             'train': train,
             'val': val,
