@@ -34,7 +34,11 @@ class Kin8nmData:
         data_path = download(cache_dir, 'kin8nm.csv', URL)
         self.df = pd.read_csv(data_path)
         table = self.df.to_numpy()
-        train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
+
+        if self.val_split != 0:
+            train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
+        else:
+            train, val = table, []
         self.data = {
             'train': train,
             'val': val,
