@@ -33,7 +33,10 @@ class ProteinStructureData:
         data_path = download(cache_dir, 'CASP.csv', URL)
         self.df = pd.read_csv(data_path)
         table = self.df.to_numpy()
-        train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
+        if self.val_split != 0:
+            train, val = train_test_split(table, test_size=self.val_split, shuffle=True)
+        else:
+            train, val = table, []
         self.data = {
             'train': train,
             'val': val,
